@@ -47,6 +47,11 @@ struct _SunOneConnectionPrivate {
 	GHashTable *wcaps;
 };
 
+#if SUNONE_DEBUG
+gchar *verbose_debug;
+gint debug_level;
+#endif
+
 static gchar *get_acls_string (GList *acls);
 static gboolean reconnect_timeout_cb (gpointer user_data);
 
@@ -615,6 +620,10 @@ sunone_connection_init (SunOneConnection *object)
 {
 	SunOneConnection *connection = SUNONE_CONNECTION (object);
 	SunOneConnectionPrivate *priv;
+#if SUNONE_DEBUG
+    SoupLogger *logger;
+    SoupLoggerLogLevel level;
+#endif
 
 	connection->priv = g_new0 (SunOneConnectionPrivate, 1);
 	priv = connection->priv;
@@ -624,6 +633,15 @@ sunone_connection_init (SunOneConnection *object)
 	priv->timeout_id = -1;
 	priv->is_open = FALSE;
 	priv->wcaps = g_hash_table_new (g_str_hash, g_str_equal);
+
+#if SUNONE_DEBUG
+    if (debug_level < 4 && debug_level >= 0)
+        level = (SoupLoggerLogLevel)debug_level;
+    else
+        level = SOUP_LOGGER_LOG_BODY;
+    logger = soup_logger_new (level, -1);
+	soup_session_add_feature (priv->soup_session, SOUP_SESSION_FEATURE (logger));
+#endif
 }
 
 
